@@ -1,8 +1,8 @@
-# $File: //member/autrijus/Locale-Maketext-Lexicon/lib/Locale/Maketext/Lexicon/Gettext.pm $ $Author: autrijus $
-# $Revision: #2 $ $Change: 320 $ $DateTime: 2002/07/02 22:32:02 $
+# $File: //member/autrijus/Locale-Maketext-Lexicon/lib/Locale/Maketext/Lexicon/Auto.pm $ $Author: autrijus $
+# $Revision: #1 $ $Change: 342 $ $DateTime: 2002/07/16 04:05:30 $
 
 package Locale::Maketext::Lexicon::Auto;
-$Locale::Maketext::Lexicon::Auto = '0.01';
+$Locale::Maketext::Lexicon::Auto::VERSION = '0.01';
 
 use strict;
 
